@@ -179,6 +179,8 @@ gnome_vfs_volume_finalize (GObject *object)
 GnomeVFSVolumeType
 gnome_vfs_volume_get_volume_type (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, GNOME_VFS_VOLUME_TYPE_MOUNTPOINT);
+
 	return volume->priv->volume_type;
 }
 
@@ -196,6 +198,8 @@ gnome_vfs_volume_get_volume_type (GnomeVFSVolume *volume)
 GnomeVFSDeviceType
 gnome_vfs_volume_get_device_type (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, GNOME_VFS_DEVICE_TYPE_UNKNOWN);
+
 	return volume->priv->device_type;
 }
 
@@ -215,6 +219,8 @@ gnome_vfs_volume_get_device_type (GnomeVFSVolume *volume)
 gulong
 gnome_vfs_volume_get_id (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, 0);
+
 	return volume->priv->id;
 }
 
@@ -230,7 +236,9 @@ GnomeVFSDrive *
 gnome_vfs_volume_get_drive (GnomeVFSVolume *volume)
 {
 	GnomeVFSDrive *drive;
-	
+
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	G_LOCK (volumes);
 	drive = gnome_vfs_drive_ref (volume->priv->drive);
 	G_UNLOCK (volumes);
@@ -277,6 +285,8 @@ gnome_vfs_volume_set_drive_private (GnomeVFSVolume     *volume,
 char *
 gnome_vfs_volume_get_device_path (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	return g_strdup (volume->priv->device_path);
 }
 
@@ -297,6 +307,8 @@ gnome_vfs_volume_get_device_path (GnomeVFSVolume *volume)
 char *
 gnome_vfs_volume_get_activation_uri (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	return g_strdup (volume->priv->activation_uri);
 }
 
@@ -316,6 +328,8 @@ gnome_vfs_volume_get_activation_uri (GnomeVFSVolume *volume)
 char *
 gnome_vfs_volume_get_hal_udi (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	return g_strdup (volume->priv->hal_udi);
 }
 
@@ -335,7 +349,7 @@ gnome_vfs_volume_get_hal_udi (GnomeVFSVolume *volume)
  * key, for traditional UNIX mounts it is set to the %mntent's 
  * %mnt_type key, for connected servers, %NULL is returned.
  *
- * As of GnomeVFS 2.15.2, the following file systems are recognized
+ * As of GnomeVFS 2.15.4, the following file systems are recognized
  * by GnomeVFS:
  *
  * <table frame="none">
@@ -360,16 +374,20 @@ gnome_vfs_volume_get_hal_udi (GnomeVFSVolume *volume)
  *    <row><entry>cdda</entry><entry>CD Digital Audio</entry><entry>No</entry></row>
  *    <row><entry>cdrom</entry><entry>CD-ROM Drive</entry><entry>No</entry></row>
  *    <row><entry>devfs</entry><entry>Hardware Device Volume</entry><entry>No</entry></row>
+ *    <row><entry>encfs</entry><entry>EncFS Volume</entry><entry>Yes</entry></row>
  *    <row><entry>ext2</entry><entry>Ext2 Linux Volume</entry><entry>Yes</entry></row>
  *    <row><entry>ext2fs</entry><entry>Ext2 Linux Volume</entry><entry>Yes</entry></row>
  *    <row><entry>ext3</entry><entry>Ext3 Linux Volume</entry><entry>Yes</entry></row>
  *    <row><entry>fat</entry><entry>MSDOS Volume</entry><entry>Yes</entry></row>
+ *    <row><entry>ffs</entry><entry>BSD Volume</entry><entry>Yes</entry></row>
  *    <row><entry>hfs</entry><entry>MacOS Volume</entry><entry>Yes</entry></row>
  *    <row><entry>hfsplus</entry><entry>MacOS Volume</entry><entry>No</entry></row>
  *    <row><entry>iso9660</entry><entry>CDROM Volume</entry><entry>No</entry></row>
  *    <row><entry>hsfs</entry><entry>Hsfs CDROM Volume</entry><entry>No</entry></row>
  *    <row><entry>jfs</entry><entry>JFS Volume</entry><entry>Yes</entry></row>
  *    <row><entry>hpfs</entry><entry>Windows NT Volume</entry><entry>No</entry></row>
+ *    <row><entry>kernfs</entry><entry>System Volume</entry><entry>No</entry></row>
+ *    <row><entry>lfs</entry><entry>BSD Volume</entry><entry>Yes</entry></row>
  *    <row><entry>linprocfs</entry><entry>System Volume</entry><entry>No</entry></row>
  *    <row><entry>mfs</entry><entry>Memory Volume</entry><entry>Yes</entry></row>
  *    <row><entry>minix</entry><entry>Minix Volume</entry><entry>No</entry></row>
@@ -380,6 +398,7 @@ gnome_vfs_volume_get_hal_udi (GnomeVFSVolume *volume)
  *    <row><entry>nwfs</entry><entry>Netware Volume</entry><entry>No</entry></row>
  *    <row><entry>proc</entry><entry>System Volume</entry><entry>No</entry></row>
  *    <row><entry>procfs</entry><entry>System Volume</entry><entry>No</entry></row>
+ *    <row><entry>ptyfs</entry><entry>System Volume</entry><entry>No</entry></row>
  *    <row><entry>reiser4</entry><entry>Reiser4 Linux Volume</entry><entry>Yes</entry></row>
  *    <row><entry>reiserfs</entry><entry>ReiserFS Linux Volume</entry><entry>Yes</entry></row>
  *    <row><entry>smbfs</entry><entry>Windows Shared Volume</entry><entry>Yes</entry></row>
@@ -389,6 +408,7 @@ gnome_vfs_volume_get_hal_udi (GnomeVFSVolume *volume)
  *    <row><entry>udfs</entry><entry>Udfs Solaris Volume</entry><entry>Yes</entry></row>
  *    <row><entry>pcfs</entry><entry>Pcfs Solaris Volume</entry><entry>Yes</entry></row>
  *    <row><entry>samfs</entry><entry>Sun SAM-QFS Volume</entry><entry>Yes</entry></row>
+ *    <row><entry>tmpfs</entry><entry>Temporary Volume</entry><entry>Yes</entry></row>
  *    <row><entry>umsdos</entry><entry>Enhanced DOS Volume</entry><entry>No</entry></row>
  *    <row><entry>vfat</entry><entry>Windows VFAT Volume</entry><entry>Yes</entry></row>
  *    <row><entry>xenix</entry><entry>Xenix Volume</entry><entry>No</entry></row>
@@ -406,6 +426,8 @@ gnome_vfs_volume_get_hal_udi (GnomeVFSVolume *volume)
 char *
 gnome_vfs_volume_get_filesystem_type (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	return g_strdup (volume->priv->filesystem_type);
 }
 
@@ -422,6 +444,8 @@ gnome_vfs_volume_get_filesystem_type (GnomeVFSVolume *volume)
 char *
 gnome_vfs_volume_get_display_name (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	return g_strdup (volume->priv->display_name);
 }
 
@@ -436,6 +460,8 @@ gnome_vfs_volume_get_display_name (GnomeVFSVolume *volume)
 char *
 gnome_vfs_volume_get_icon (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, NULL);
+
 	return g_strdup (volume->priv->icon);
 }
 
@@ -454,6 +480,8 @@ gnome_vfs_volume_get_icon (GnomeVFSVolume *volume)
 gboolean
 gnome_vfs_volume_is_user_visible (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, FALSE);
+
 	return volume->priv->is_user_visible;
 }
 
@@ -475,6 +503,8 @@ gnome_vfs_volume_is_user_visible (GnomeVFSVolume *volume)
 gboolean
 gnome_vfs_volume_is_read_only (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, FALSE);
+
 	return volume->priv->is_read_only;
 }
 
@@ -496,6 +526,8 @@ gnome_vfs_volume_is_read_only (GnomeVFSVolume *volume)
 gboolean
 gnome_vfs_volume_is_mounted (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, FALSE);
+
 	return volume->priv->is_mounted;
 }
 
@@ -523,6 +555,8 @@ gnome_vfs_volume_is_mounted (GnomeVFSVolume *volume)
 gboolean
 gnome_vfs_volume_handles_trash (GnomeVFSVolume *volume)
 {
+	g_return_val_if_fail (volume != NULL, FALSE);
+
 	if (volume->priv->device_type == GNOME_VFS_DEVICE_TYPE_AUTOFS) {
 		return FALSE;
 	}
